function [LFX_Response, f_6dB] = LFX_Response_fnc(f, Response, Response_Ref, flow, fhigh)

% [LFX_Response, f_6dB] = LFX_Response_fnc(f, SP, LW, 300, 10000)
% LFX is defined by equation 7,
% LFX = log10(xSP?6dB.re:y _ LW(300Hz?10kHz) (7)
% where LFX is the log10 of the first frequency x_SP below 300 Hz in the sound power curve, 
% that is -6 dB relative to the mean level y_LW measured in listening window (LW) between 300 Hz-10 kHz.
% LFX is log-transformed to produce a linear relationship between the variable LFX and preference rating. 
% The sound power curve (SP) is used for the calculation because it better defines the true bass output of
% the loudspeaker, particularly speakers that have rear-firing ports.
% Use for the calculation of the Olive metric with the ON and 300 10000

% flowindx         = find(f <= flow, 1, 'last');
% fhigindx         = find(f <= fhigh, 1, 'last');

[~,flowindx]     = min( abs( f - flow ) );
[~,fhigindx]     = min( abs( f - fhigh ) );
Avg_flow_fhigh   = mean( Response_Ref( flowindx:fhigindx ),1 );
Avg_6dB          = Avg_flow_fhigh - 6;

% f_6dB            = f( find( Response( 1:flowindx ) <= Avg_6dB, 1, 'last' ) );
f_6dB            = f( find( Response( 1:flowindx ) >= Avg_6dB, 1, 'first' ) );
LFX_Response     = log10( f_6dB );






