% Calculation of LW, ER, SP and PIR directly from the Klippel NFS raw data 
% 202200811 the ER calculation is not correct and therefore the PIR is wrong
% Streamlined and better figure handling
% The measurements and scripts provided here are copyrighted by Audio Science Review LLC.
% 
% This work is licensed under the Creative Commons
% Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy
% of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/ or send
% a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
% 
% Highlights of the license are:
% 
% You are free to:
% - Share: copy and redistribute the material in any medium or format
% - Adapt: remix, transform, and build upon the material
% 
% Under the following terms:
% - Attribution: you must give appropriate credit (link and mention of Audio
%   Science Review, https://www.audiosciencereview.com/), provide a link to the
%   license, and indicate if changes were made. You may do so in any reasonable
%   manner, but not in any way that suggests the licensor endorses you or your
%   use.
% - Non Commercial: you may not use the material for commercial purposes.
% - Share Alike: if you remix, transform, or build upon the material, you must
%   distribute your contributions under the same license as the original.
% - No additional restrictions: you may not apply legal terms or technological
%   measures that legally restrict others from doing anything the license permits.
% ------------------------------------------------------------------------------
% Clear variables and house keeping
% ------------------------------------------------------------------------------
clear
close all
clc

% ------------------------------------------------------------------------------
% A prompt will appear to retrieve the Name of the DUT to include it in the 
% titles and name of the saved graphs
% ------------------------------------------------------------------------------
prompt1              = {'Enter the Name of the DUT:'};
dlg_title1           = 'Input Name';
num_lines1           = 1;
AddOpts.Resize       ='on';
AddOpts.WindowStyle  ='normal';
AddOpts.Interpreter  ='tex';
answer1              = inputdlg(prompt1,dlg_title1,num_lines1);
cat1                 = {'a'};
measurement1         = cell2struct(answer1,cat1,1);
DUT_Name             = measurement1.a;

% ------------------------------------------------------------------------------
% Set some variables for the rest of the script
% ------------------------------------------------------------------------------
Pref       = 0.00002;
startRow   = 4;
endRow     = 1000; % Change here for the correct number of lines/rows in the NFS data

% ------------------------------------------------------------------------------
% Load NFS Measurements data Horizontal SPL and Vertical SPL in Octave
% 70 curves (72 minus (ON and 180) which may be measured twice)
% ------------------------------------------------------------------------------
formatSpec = '%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%[^\n]';
delimiter  = '\t';

fileID     = fopen('SPL Horizontal.txt','r');
SPLH       = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter,'HeaderLines', startRow(1)-1, 'EndOfLine', '\n');
fclose(fileID);

fileID     = fopen('SPL Vertical.txt','r');
SPLV       = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter,'HeaderLines', startRow(1)-1, 'EndOfLine', '\n');
f          = SPLH{1,1};
fclose(fileID);

for k = 1 % just hides the calculation of p^2
% -------------------------------------------------------------------------
% Energy 
% -------------------------------------------------------------------------
% SPL = 10*log10( (p/Pref)^2 ); 
% 10. ^ (SPL/10) = (p/Pref)^2;
% p^2 = 10. ^ (SPL/10) * Pref^2;

% Horizontal
ON              = SPLH{1,2};
ONp2            = 10 .^ (ON/10)*Pref^2;
H10deg          = SPLH{1,4};
H10degp2        = 10 .^ (H10deg/10)*Pref^2;
Hneg10deg       = SPLH{1,6};
Hneg10degp2     = 10 .^ (Hneg10deg/10)*Pref^2;
H20deg          = SPLH{1,8};
H20degp2        = 10 .^ (H20deg/10)*Pref^2;
Hneg20deg       = SPLH{1,10};
Hneg20degp2     = 10 .^ (Hneg20deg/10)*Pref^2;
H30deg          = SPLH{1,12};
H30degp2        = 10 .^ (H30deg/10)*Pref^2;
Hneg30deg       = SPLH{1,14};
Hneg30degp2     = 10 .^ (Hneg30deg/10)*Pref^2;
H40deg          = SPLH{1,16};
H40degp2        = 10 .^ (H40deg/10)*Pref^2;
Hneg40deg       = SPLH{1,18};
Hneg40degp2     = 10 .^ (Hneg40deg/10)*Pref^2;
H50deg          = SPLH{1,20};
H50degp2        = 10 .^ (H50deg/10)*Pref^2;
Hneg50deg       = SPLH{1,22};
Hneg50degp2     = 10 .^ (Hneg50deg/10)*Pref^2;
H60deg          = SPLH{1,24};
H60degp2        = 10 .^ (H60deg/10)*Pref^2;
Hneg60deg       = SPLH{1,26};
Hneg60degp2     = 10 .^ (Hneg60deg/10)*Pref^2;
H70deg          = SPLH{1,28};
H70degp2        = 10 .^ (H70deg/10)*Pref^2;
Hneg70deg       = SPLH{1,30};
Hneg70degp2     = 10 .^ (Hneg70deg/10)*Pref^2;
H80deg          = SPLH{1,32};
H80degp2        = 10 .^ (H80deg/10)*Pref^2;
Hneg80deg       = SPLH{1,34};
Hneg80degp2     = 10 .^ (Hneg80deg/10)*Pref^2;
H90deg          = SPLH{1,36};
H90degp2        = 10 .^ (H90deg/10)*Pref^2;
Hneg90deg       = SPLH{1,38};
Hneg90degp2     = 10 .^ (Hneg90deg/10)*Pref^2;
H100deg         = SPLH{1,40};
H100degp2       = 10 .^ (H100deg/10)*Pref^2;
Hneg100deg      = SPLH{1,42};
Hneg100degp2    = 10 .^ (Hneg100deg/10)*Pref^2;
H110deg         = SPLH{1,44};
H110degp2       = 10 .^ (H110deg/10)*Pref^2;
Hneg110deg      = SPLH{1,46};
Hneg110degp2    = 10 .^ (Hneg110deg/10)*Pref^2;
H120deg         = SPLH{1,48};
H120degp2       = 10 .^ (H120deg/10)*Pref^2;
Hneg120deg      = SPLH{1,50};
Hneg120degp2    = 10 .^ (Hneg120deg/10)*Pref^2;
H130deg         = SPLH{1,52};
H130degp2       = 10 .^ (H130deg/10)*Pref^2;
Hneg130deg      = SPLH{1,54};
Hneg130degp2    = 10 .^ (Hneg130deg/10)*Pref^2;
H140deg         = SPLH{1,56};
H140degp2       = 10 .^ (H140deg/10)*Pref^2;
Hneg140deg      = SPLH{1,58};
Hneg140degp2    = 10 .^ (Hneg140deg/10)*Pref^2;
H150deg         = SPLH{1,60};
H150degp2       = 10 .^ (H150deg/10)*Pref^2;
Hneg150deg      = SPLH{1,62};
Hneg150degp2    = 10 .^ (Hneg150deg/10)*Pref^2;
H160deg         = SPLH{1,64};
H160degp2       = 10 .^ (H160deg/10)*Pref^2;
Hneg160deg      = SPLH{1,66};
Hneg160degp2    = 10 .^ (Hneg160deg/10)*Pref^2;
H170deg         = SPLH{1,68};
H170degp2       = 10 .^ (H170deg/10)*Pref^2;
Hneg170deg      = SPLH{1,70};
Hneg170degp2    = 10 .^ (Hneg170deg/10)*Pref^2;
H180deg         = SPLH{1,72};
H180degp2       = 10 .^ (H180deg/10)*Pref^2;

% Vertical
V10deg          = SPLV{1,4};
V10degp2        = 10 .^ (V10deg/10)*Pref^2;
Vneg10deg       = SPLV{1,6};
Vneg10degp2     = 10 .^ (Vneg10deg/10)*Pref^2;
V20deg          = SPLV{1,8};
V20degp2        = 10 .^ (V20deg/10)*Pref^2;
Vneg20deg       = SPLV{1,10};
Vneg20degp2     = 10 .^ (Vneg20deg/10)*Pref^2;
V30deg          = SPLV{1,12};
V30degp2        = 10 .^ (V30deg/10)*Pref^2;
Vneg30deg       = SPLV{1,14};
Vneg30degp2     = 10 .^ (Vneg30deg/10)*Pref^2;
V40deg          = SPLV{1,16};
V40degp2        = 10 .^ (V40deg/10)*Pref^2;
Vneg40deg       = SPLV{1,18};
Vneg40degp2     = 10 .^ (Vneg40deg/10)*Pref^2;
V50deg          = SPLV{1,20};
V50degp2        = 10 .^ (V50deg/10)*Pref^2;
Vneg50deg       = SPLV{1,22};
Vneg50degp2     = 10 .^ (Vneg50deg/10)*Pref^2;
V60deg          = SPLV{1,24};
V60degp2        = 10 .^ (V60deg/10)*Pref^2;
Vneg60deg       = SPLV{1,26};
Vneg60degp2     = 10 .^ (Vneg60deg/10)*Pref^2;
V70deg          = SPLV{1,28};
V70degp2        = 10 .^ (V70deg/10)*Pref^2;
Vneg70deg       = SPLV{1,30};
Vneg70degp2     = 10 .^ (Vneg70deg/10)*Pref^2;
V80deg          = SPLV{1,32};
V80degp2        = 10 .^ (V80deg/10)*Pref^2;
Vneg80deg       = SPLV{1,34};
Vneg80degp2     = 10 .^ (Vneg80deg/10)*Pref^2;
V90deg          = SPLV{1,36};
V90degp2        = 10 .^ (V90deg/10)*Pref^2;
Vneg90deg       = SPLV{1,38};
Vneg90degp2     = 10 .^ (Vneg90deg/10)*Pref^2;
V100deg         = SPLV{1,40};
V100degp2       = 10 .^ (V100deg/10)*Pref^2;
Vneg100deg      = SPLV{1,42};
Vneg100degp2    = 10 .^ (Vneg100deg/10)*Pref^2;
V110deg         = SPLV{1,44};
V110degp2       = 10 .^ (V110deg/10)*Pref^2;
Vneg110deg      = SPLV{1,46};
Vneg110degp2    = 10 .^ (Vneg110deg/10)*Pref^2;
V120deg         = SPLV{1,48};
V120degp2       = 10 .^ (V120deg/10)*Pref^2;
Vneg120deg      = SPLV{1,50};
Vneg120degp2    = 10 .^ (Vneg120deg/10)*Pref^2;
V130deg         = SPLV{1,52};
V130degp2       = 10 .^ (V130deg/10)*Pref^2;
Vneg130deg      = SPLV{1,54};
Vneg130degp2    = 10 .^ (Vneg130deg/10)*Pref^2;
V140deg         = SPLV{1,56};
V140degp2       = 10 .^ (V140deg/10)*Pref^2;
Vneg140deg      = SPLV{1,58};
Vneg140degp2    = 10 .^ (Vneg140deg/10)*Pref^2;
V150deg         = SPLV{1,60};
V150degp2       = 10 .^ (V150deg/10)*Pref^2;
Vneg150deg      = SPLV{1,62};
Vneg150degp2    = 10 .^ (Vneg150deg/10)*Pref^2;
V160deg         = SPLV{1,64};
V160degp2       = 10 .^ (V160deg/10)*Pref^2;
Vneg160deg      = SPLV{1,66};
Vneg160degp2    = 10 .^ (Vneg160deg/10)*Pref^2;
V170deg         = SPLV{1,68};
V170degp2       = 10 .^ (V170deg/10)*Pref^2;
Vneg170deg      = SPLV{1,70};
Vneg170degp2    = 10 .^ (Vneg170deg/10)*Pref^2;
end

% ------------------------------------------------------------------------------
% LW: Listening Window calculation
% LW  0,  +/-10h, +/-20h, +/-30h, +/-10v do energy average of the 9 curves 
% ------------------------------------------------------------------------------
LW_calc       = 10*log10(((1 * ONp2 + ...
                           1 * H10degp2 + ...
                           1 * Hneg10degp2 + ...
                           1 * H20degp2 + ...
                           1 * Hneg20degp2 + ...
                           1 * H30degp2 + ...
                           1 * Hneg30degp2 + ...
                           1 * V10degp2 + ...
                           1 * Vneg10degp2) / 9 ) / Pref^2);
                       
% ------------------------------------------------------------------------------
% ER: Early Reflexions calculation
% Floor:     -20v, -30v, -40v do energy average of the 3 curves                                            
% Ceiling:   +40v, +50v, +60v do energy average of the 3 curves 
% Front Wall:  0,  +/-10h, +/-20h, +/-0h do energy average of the 7 curves 
% Side Wall: +/-40h,  +/-50h,  +/-60h,  +/-70h,  +/-80h do energy average  of the 10 curves 
% Rear Wall: +/-90h   +/-100h, +/-110h, +/-120h, +/-130h, +/-140h, +/-150h, +/-160h, +/-170h, 180 
% do energy average of the 19 curves
% ------------------------------------------------------------------------------
Floor_bounce      = 10*log10( (Vneg20degp2 + Vneg30degp2  + Vneg40degp2 ) / 3 / Pref^2); 

Ceiling_bounce    = 10*log10( (V40degp2    + V50degp2     + V60degp2    ) / 3 / Pref^2); 

Front_wall_bounce = 10*log10( (ONp2        + H10degp2     + Hneg10degp2 + Hneg20degp2  + H20degp2  + Hneg30degp2  + ...
                               H30degp2 ) / 7 / Pref^2);

Side_wall_bounce  = 10*log10( (H40degp2    + Hneg40degp2  + H50degp2    + Hneg50degp2  + H60degp2  + Hneg60degp2  + ...
                               H70degp2    + Hneg70degp2  + H80degp2    + Hneg80degp2 ) / 10 / Pref^2);
 
Rear_wall_bounce  = 10*log10( (H90degp2    + Hneg90degp2  + H100degp2   + Hneg100degp2 + H110degp2 + Hneg110degp2 + ...
                               H120degp2   + Hneg120degp2 + H130degp2   + Hneg130degp2 + H140degp2 + Hneg140degp2 + ...
                               H150degp2   + Hneg150degp2 + H160degp2   + Hneg160degp2 + H170degp2 + Hneg170degp2 + ...
                               H180degp2 ) / 19 / Pref^2);
                                                      
ER_calc   =  10*log10( (10 .^ (Floor_bounce/10)*Pref^2      + 10 .^ (Ceiling_bounce/10)*Pref^2   + ...
                        10 .^ (Front_wall_bounce/10)*Pref^2 + 10 .^ (Side_wall_bounce/10)*Pref^2 + ...
                        10 .^ (Rear_wall_bounce/10)*Pref^2 ) / 5 / Pref^2);
                    
% ------------------------------------------------------------------------------
% ERDI calculation 
% ERDI_calc = LW_calc - ER_calc;
% ------------------------------------------------------------------------------
ERDI_calc = LW_calc - ER_calc;

% ------------------------------------------------------------------------------
% SP: Sound Power calculation
% weights W are applied to vertical V and Horizontal H
% Energy average of p^2 sum(W*(P/Pref)^2)/sum(w)
% ------------------------------------------------------------------------------
W = [
0.0006044860 % 00 & 180deg               - 2
0.0047301890 % +/-10 & +/-170deg V and H - 8
0.0089550270 % +/-20 & +/-160deg V and H - 8
0.0123873540 % +/-30 & +/-150deg V and H - 8
0.0149896110 % +/-40 & +/-140deg V and H - 8
0.0168681540 % +/-50 & +/-130deg V and H - 8
0.0181659620 % +/-60 & +/-120deg V and H - 8
0.0190067440 % +/-70 & +/-110deg V and H - 8
0.0194777870 % +/-80 & +/-100deg V and H - 8
0.0196293730 % +/-90deg          V and H - 4
]; 

SP_calc = 10*log10( (W(1)*ONp2 + ... % Axis (only once!)
 W(2)*H10degp2  + W(2)*Hneg10degp2  + W(3)*H20degp2  + W(3)*Hneg20degp2  + W(4)*H30degp2  + W(4)*Hneg30degp2  + ...
 W(5)*H40degp2  + W(5)*Hneg40degp2  + W(6)*H50degp2  + W(6)*Hneg50degp2  + W(7)*H60degp2  + W(7)*Hneg60degp2  + ... 
 W(8)*H70degp2  + W(8)*Hneg70degp2  + W(9)*H80degp2  + W(9)*Hneg80degp2  + W(10)*H90degp2 + W(10)*Hneg90degp2 + ...
 W(9)*H100degp2 + W(9)*Hneg100degp2 + W(8)*H110degp2 + W(8)*Hneg110degp2 + W(7)*H120degp2 + W(7)*Hneg120degp2 + ...
 W(6)*H130degp2 + W(6)*Hneg130degp2 + W(5)*H140degp2 + W(5)*Hneg140degp2 + W(4)*H150degp2 + W(4)*Hneg150degp2 + ...
 W(3)*H160degp2 + W(3)*Hneg160degp2 + W(2)*H170degp2 + W(2)*Hneg170degp2 + ... % Horizontal
 W(1)*H180degp2 + ...  % Back (only once!)
 W(2)*V10degp2  + W(2)*Vneg10degp2  + W(3)*V20degp2  + W(3)*Vneg20degp2  + W(4)*V30degp2  + W(4)*Vneg30degp2  + ...
 W(5)*V40degp2  + W(5)*Vneg40degp2  + W(6)*V50degp2  + W(6)*Vneg50degp2  + W(7)*V60degp2  + W(7)*Vneg60degp2  + ... 
 W(8)*V70degp2  + W(8)*Vneg70degp2  + W(9)*V80degp2  + W(9)*Vneg80degp2  + W(10)*V90degp2 + W(10)*Vneg90degp2 + ...
 W(9)*V100degp2 + W(9)*Vneg100degp2 + W(8)*V110degp2 + W(8)*Vneg110degp2 + W(7)*V120degp2 + W(7)*Vneg120degp2 + ...
 W(6)*V130degp2 + W(6)*Vneg130degp2 + W(5)*V140degp2 + W(5)*Vneg140degp2 + W(4)*V150degp2 + W(4)*Vneg150degp2 + ...
 W(3)*V160degp2 + W(3)*Vneg160degp2 + W(2)*V170degp2 + W(2)*Vneg170degp2) / ... % Vertical
( 2*W(1) + 8*W(2) + 8*W(3) + 8*W(4) + 8*W(5) + 8*W(6) + 8*W(7) + 8*W(8) + 8*W(9) + 4*W(10) ) / Pref^2); % Sum weights

% ------------------------------------------------------------------------------
% SPDI calculation 
% Classic definition is SPDI = Axis_ref - SP but for CEA2034 it is changed to
% SPDI_calc = LW_calc - SP_calc;
% ------------------------------------------------------------------------------
SPDI_calc = LW_calc - SP_calc;

% ------------------------------------------------------------------------------
% DI offset calculation 
% ------------------------------------------------------------------------------
max_SPL   = max(ON);
max_scale = 10*(round(max_SPL/10))+5;
min_scale = max_scale - 50;
DIoffset  = min_scale * ones(length(f),1);

% ------------------------------------------------------------------------------
% PIR: predicted In-room Response calculation
% PIR: 0.12LW + 0.44ER + 0.44SP do energy average of the 3 curves
% Plot PIR Slope 100 - 16000Hz
% ------------------------------------------------------------------------------
PIR_calc_calc = 10*log10(( 0.12 * 10 .^ (LW_calc/10) * Pref^2 + ...
                           0.44 * 10 .^ (ER_calc/10) * Pref^2 + ...
                           0.44 * 10 .^ (SP_calc/10) * Pref^2 ) / Pref^2 ) ;
 
[~,flowindx]  = min(abs(f-100));
[~,fhigindx]  = min(abs(f-16000));
[P,S]         = polyfit(log(f(flowindx:fhigindx)), PIR_calc_calc(flowindx:fhigindx), 1);
Regression    = P(2) + P(1)*log(f(flowindx:fhigindx)); 
SM_PIR        = 1 - (S.normr/norm(PIR_calc_calc(flowindx:fhigindx) - mean(PIR_calc_calc(flowindx:fhigindx))))^2;
                          
% ------------------------------------------------------------------------------
% Save the corrected Spinorama + PIR with the corrected ER and PIR 
% plot the corrected Spinorama + PIR corrected data only
% Save the corresponding graph
% ------------------------------------------------------------------------------    
Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data = [f ON LW_calc ER_calc PIR_calc_calc SP_calc SPDI_calc ERDI_calc DIoffset];
Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.Name = DUT_Name;

if exist('OCTAVE_VERSION', 'builtin') ~= 0
save Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.mat Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset -mat7-binary
  else
save Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.mat Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset
end    
    
    
% ------------------------------------------------------------------------------
% Plot final data 
% ------------------------------------------------------------------------------
        
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(1)
  else
  figure('Name','1', 'WindowState','maximized')
  pause(1)
end
    set(gcf,'Name','Spinorama Corrected Data')
    semilogx(Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,1),Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,2),'k','LineWidth',2)
    hold on
    semilogx(Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,1),Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,3),'g','LineWidth',2)
    semilogx(Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,1),Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,4),'r','LineWidth',2)
    semilogx(Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,1),Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,5),'c','LineWidth',2)
    semilogx(Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,1),Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,6),'b','LineWidth',2)
    semilogx(Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,1),Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,7) + ...
             Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,9),'color',[0.5 0.0 0.5],'LineWidth',2)
    semilogx(Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,1),Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,8) + ...
             Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset.data(:,9),'color',[1.0 0.5 0.0],'LineWidth',2)
    legend('ON', 'LW', 'ER', 'PIR', 'SP', 'SPDI + DIoffset', 'ERDI + DIoffset','location','northeastoutside')
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid minor
    title([DUT_Name,' Spinorama Correct data'],'Fontsize',16)
    xlim([20 20000])
    ylim([min_scale max_scale])
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' Spinorama Correct data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', [DUT_Name,' Spinorama Correct data.png']) 
end  

% ------------------------------------------------------------------------------
% End of script
% ------------------------------------------------------------------------------
 

    

    



