% Plot directivity data from the Klippel NFS raw data 
% Interpolation is used for smoother plots
% 20200813
% The measurements and scripts provided here are copyrighted by Audio Science Review LLC.
% 
% This work is licensed under the Creative Commons
% Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy
% of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/ or send
% a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
% 
% Highlights of the license are:
% 
% You are free to:
% - Share: copy and redistribute the material in any medium or format
% - Adapt: remix, transform, and build upon the material
% 
% Under the following terms:
% - Attribution: you must give appropriate credit (link and mention of Audio
%   Science Review, https://www.audiosciencereview.com/), provide a link to the
%   license, and indicate if changes were made. You may do so in any reasonable
%   manner, but not in any way that suggests the licensor endorses you or your
%   use.
% - Non Commercial: you may not use the material for commercial purposes.
% - Share Alike: if you remix, transform, or build upon the material, you must
%   distribute your contributions under the same license as the original.
% - No additional restrictions: you may not apply legal terms or technological
%   measures that legally restrict others from doing anything the license permits.
% ------------------------------------------------------------------------------
% Clear variables and house keeping
% ------------------------------------------------------------------------------
clear
close all
clc

% ------------------------------------------------------------------------------
% A prompt will appear to retrieve the Name of the DUT to include it in the 
% titles and name of the saved graphs
% ------------------------------------------------------------------------------
prompt1              = {'Enter the Name of the DUT:'};
dlg_title1           = 'Input Name';
num_lines1           = 1;
AddOpts.Resize       ='on';
AddOpts.WindowStyle  ='normal';
AddOpts.Interpreter  ='tex';
answer1              = inputdlg(prompt1,dlg_title1,num_lines1);
cat1                 = {'a'};
measurement1         = cell2struct(answer1,cat1,1);
DUT_Name             = measurement1.a;

% ------------------------------------------------------------------------------
% Set some variables for the rest of the script
% ------------------------------------------------------------------------------
Pref               = 0.00002;
startRow           = 4;
endRow             = 1000; % Change here for the correct number of lines/rows in the NFS data

% ------------------------------------------------------------------------------
% Load NFS Measurements data Horizontal SPL and Vertical SPL in Octave
% 70 curves (72 minus (ON and 180) which may be measured twice)
% ------------------------------------------------------------------------------
formatSpec = '%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%[^\n]';
delimiter  = '\t';

fileID     = fopen('SPL Horizontal.txt','r');
SPLH       = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter,'HeaderLines', startRow(1)-1, 'EndOfLine', '\n');
fclose(fileID);

fileID     = fopen('SPL Vertical.txt','r');
SPLV       = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter,'HeaderLines', startRow(1)-1, 'EndOfLine', '\n');
f          = SPLH{1,1};
fclose(fileID);

for k = 1 % just hides the calculation of p^2
% -------------------------------------------------------------------------
% Energy 
% -------------------------------------------------------------------------
% SPL = 10*log10( (p/Pref)^2 ); 
% 10. ^ (SPL/10) = (p/Pref)^2;
% p^2 = 10. ^ (SPL/10) * Pref^2;

% Horizontal
ON              = SPLH{1,2};
ONp2            = 10 .^ (ON/10)*Pref^2;
H10deg          = SPLH{1,4};
H10degp2        = 10 .^ (H10deg/10)*Pref^2;
Hneg10deg       = SPLH{1,6};
Hneg10degp2     = 10 .^ (Hneg10deg/10)*Pref^2;
H20deg          = SPLH{1,8};
H20degp2        = 10 .^ (H20deg/10)*Pref^2;
Hneg20deg       = SPLH{1,10};
Hneg20degp2     = 10 .^ (Hneg20deg/10)*Pref^2;
H30deg          = SPLH{1,12};
H30degp2        = 10 .^ (H30deg/10)*Pref^2;
Hneg30deg       = SPLH{1,14};
Hneg30degp2     = 10 .^ (Hneg30deg/10)*Pref^2;
H40deg          = SPLH{1,16};
H40degp2        = 10 .^ (H40deg/10)*Pref^2;
Hneg40deg       = SPLH{1,18};
Hneg40degp2     = 10 .^ (Hneg40deg/10)*Pref^2;
H50deg          = SPLH{1,20};
H50degp2        = 10 .^ (H50deg/10)*Pref^2;
Hneg50deg       = SPLH{1,22};
Hneg50degp2     = 10 .^ (Hneg50deg/10)*Pref^2;
H60deg          = SPLH{1,24};
H60degp2        = 10 .^ (H60deg/10)*Pref^2;
Hneg60deg       = SPLH{1,26};
Hneg60degp2     = 10 .^ (Hneg60deg/10)*Pref^2;
H70deg          = SPLH{1,28};
H70degp2        = 10 .^ (H70deg/10)*Pref^2;
Hneg70deg       = SPLH{1,30};
Hneg70degp2     = 10 .^ (Hneg70deg/10)*Pref^2;
H80deg          = SPLH{1,32};
H80degp2        = 10 .^ (H80deg/10)*Pref^2;
Hneg80deg       = SPLH{1,34};
Hneg80degp2     = 10 .^ (Hneg80deg/10)*Pref^2;
H90deg          = SPLH{1,36};
H90degp2        = 10 .^ (H90deg/10)*Pref^2;
Hneg90deg       = SPLH{1,38};
Hneg90degp2     = 10 .^ (Hneg90deg/10)*Pref^2;
H100deg         = SPLH{1,40};
H100degp2       = 10 .^ (H100deg/10)*Pref^2;
Hneg100deg      = SPLH{1,42};
Hneg100degp2    = 10 .^ (Hneg100deg/10)*Pref^2;
H110deg         = SPLH{1,44};
H110degp2       = 10 .^ (H110deg/10)*Pref^2;
Hneg110deg      = SPLH{1,46};
Hneg110degp2    = 10 .^ (Hneg110deg/10)*Pref^2;
H120deg         = SPLH{1,48};
H120degp2       = 10 .^ (H120deg/10)*Pref^2;
Hneg120deg      = SPLH{1,50};
Hneg120degp2    = 10 .^ (Hneg120deg/10)*Pref^2;
H130deg         = SPLH{1,52};
H130degp2       = 10 .^ (H130deg/10)*Pref^2;
Hneg130deg      = SPLH{1,54};
Hneg130degp2    = 10 .^ (Hneg130deg/10)*Pref^2;
H140deg         = SPLH{1,56};
H140degp2       = 10 .^ (H140deg/10)*Pref^2;
Hneg140deg      = SPLH{1,58};
Hneg140degp2    = 10 .^ (Hneg140deg/10)*Pref^2;
H150deg         = SPLH{1,60};
H150degp2       = 10 .^ (H150deg/10)*Pref^2;
Hneg150deg      = SPLH{1,62};
Hneg150degp2    = 10 .^ (Hneg150deg/10)*Pref^2;
H160deg         = SPLH{1,64};
H160degp2       = 10 .^ (H160deg/10)*Pref^2;
Hneg160deg      = SPLH{1,66};
Hneg160degp2    = 10 .^ (Hneg160deg/10)*Pref^2;
H170deg         = SPLH{1,68};
H170degp2       = 10 .^ (H170deg/10)*Pref^2;
Hneg170deg      = SPLH{1,70};
Hneg170degp2    = 10 .^ (Hneg170deg/10)*Pref^2;
H180deg         = SPLH{1,72};
H180degp2       = 10 .^ (H180deg/10)*Pref^2;

% Vertical
V10deg          = SPLV{1,4};
V10degp2        = 10 .^ (V10deg/10)*Pref^2;
Vneg10deg       = SPLV{1,6};
Vneg10degp2     = 10 .^ (Vneg10deg/10)*Pref^2;
V20deg          = SPLV{1,8};
V20degp2        = 10 .^ (V20deg/10)*Pref^2;
Vneg20deg       = SPLV{1,10};
Vneg20degp2     = 10 .^ (Vneg20deg/10)*Pref^2;
V30deg          = SPLV{1,12};
V30degp2        = 10 .^ (V30deg/10)*Pref^2;
Vneg30deg       = SPLV{1,14};
Vneg30degp2     = 10 .^ (Vneg30deg/10)*Pref^2;
V40deg          = SPLV{1,16};
V40degp2        = 10 .^ (V40deg/10)*Pref^2;
Vneg40deg       = SPLV{1,18};
Vneg40degp2     = 10 .^ (Vneg40deg/10)*Pref^2;
V50deg          = SPLV{1,20};
V50degp2        = 10 .^ (V50deg/10)*Pref^2;
Vneg50deg       = SPLV{1,22};
Vneg50degp2     = 10 .^ (Vneg50deg/10)*Pref^2;
V60deg          = SPLV{1,24};
V60degp2        = 10 .^ (V60deg/10)*Pref^2;
Vneg60deg       = SPLV{1,26};
Vneg60degp2     = 10 .^ (Vneg60deg/10)*Pref^2;
V70deg          = SPLV{1,28};
V70degp2        = 10 .^ (V70deg/10)*Pref^2;
Vneg70deg       = SPLV{1,30};
Vneg70degp2     = 10 .^ (Vneg70deg/10)*Pref^2;
V80deg          = SPLV{1,32};
V80degp2        = 10 .^ (V80deg/10)*Pref^2;
Vneg80deg       = SPLV{1,34};
Vneg80degp2     = 10 .^ (Vneg80deg/10)*Pref^2;
V90deg          = SPLV{1,36};
V90degp2        = 10 .^ (V90deg/10)*Pref^2;
Vneg90deg       = SPLV{1,38};
Vneg90degp2     = 10 .^ (Vneg90deg/10)*Pref^2;
V100deg         = SPLV{1,40};
V100degp2       = 10 .^ (V100deg/10)*Pref^2;
Vneg100deg      = SPLV{1,42};
Vneg100degp2    = 10 .^ (Vneg100deg/10)*Pref^2;
V110deg         = SPLV{1,44};
V110degp2       = 10 .^ (V110deg/10)*Pref^2;
Vneg110deg      = SPLV{1,46};
Vneg110degp2    = 10 .^ (Vneg110deg/10)*Pref^2;
V120deg         = SPLV{1,48};
V120degp2       = 10 .^ (V120deg/10)*Pref^2;
Vneg120deg      = SPLV{1,50};
Vneg120degp2    = 10 .^ (Vneg120deg/10)*Pref^2;
V130deg         = SPLV{1,52};
V130degp2       = 10 .^ (V130deg/10)*Pref^2;
Vneg130deg      = SPLV{1,54};
Vneg130degp2    = 10 .^ (Vneg130deg/10)*Pref^2;
V140deg         = SPLV{1,56};
V140degp2       = 10 .^ (V140deg/10)*Pref^2;
Vneg140deg      = SPLV{1,58};
Vneg140degp2    = 10 .^ (Vneg140deg/10)*Pref^2;
V150deg         = SPLV{1,60};
V150degp2       = 10 .^ (V150deg/10)*Pref^2;
Vneg150deg      = SPLV{1,62};
Vneg150degp2    = 10 .^ (Vneg150deg/10)*Pref^2;
V160deg         = SPLV{1,64};
V160degp2       = 10 .^ (V160deg/10)*Pref^2;
Vneg160deg      = SPLV{1,66};
Vneg160degp2    = 10 .^ (Vneg160deg/10)*Pref^2;
V170deg         = SPLV{1,68};
V170degp2       = 10 .^ (V170deg/10)*Pref^2;
Vneg170deg      = SPLV{1,70};
Vneg170degp2    = 10 .^ (Vneg170deg/10)*Pref^2;
end

% ------------------------------------------------------------------------------
% LW: Listening Window calculation
% LW  0,  +/-10h, +/-20h, +/-30h, +/-10v do energy average of the 9 curves 
% ------------------------------------------------------------------------------
LW_calc       = 10*log10(((1 * ONp2 + ...
                           1 * H10degp2 + ...
                           1 * Hneg10degp2 + ...
                           1 * H20degp2 + ...
                           1 * Hneg20degp2 + ...
                           1 * H30degp2 + ...
                           1 * Hneg30degp2 + ...
                           1 * V10degp2 + ...
                           1 * Vneg10degp2) / 9 ) / Pref^2);
                       
% ------------------------------------------------------------------------------
% Set Normalization Axis
% ------------------------------------------------------------------------------
Axis4normalization = SPLH{1,2}; % SPLH{1,2} = ON
% Axis4normalization = LW_calc; 

% ------------------------------------------------------------------------------
% Set Graph range
% ------------------------------------------------------------------------------
max_SPL            = max(ON);
max_scale          = 10*(round(max_SPL/10))+10;
min_scale          = max_scale - 50;

% ------------------------------------------------------------------------------
% Set Angle Vectors
% ------------------------------------------------------------------------------
deg                = linspace(-170, 180, 36);  % Raw data 10deg resolution
deg_interp         = linspace(-170, 180, 71);  % Interpolated 5deg resolution

% ------------------------------------------------------------------------------
% Prepare Surfaces
% ------------------------------------------------------------------------------
% Raw -170deg to 180deg both for H and V
for k = 1:18
    SPLH_surf(:,k)    = SPLH{1,70-4*k+4}(:);
    SPLH_surf(:,18+k) = SPLH{1,4*k}(:);
    SPLV_surf(:,k)    = SPLV{1,70-4*k+4}(:);
    SPLV_surf(:,18+k) = SPLV{1,4*k}(:);
end
    
% Normalized -170deg to 180deg both for H and V
for k = 1:18
    SPLH_surf_normalized(:,k)    = SPLH{1,70-4*k+4}(:) - Axis4normalization;
    SPLH_surf_normalized(:,18+k) = SPLH{1,4*k}(:) - Axis4normalization;
    SPLV_surf_normalized(:,k)    = SPLV{1,70-4*k+4}(:) - Axis4normalization;
    SPLV_surf_normalized(:,18+k) = SPLV{1,4*k}(:) - Axis4normalization;
end

% Interpolation for higher angular resolution both for H and V
% ZI = griddata(x,y,z,XI,YI)  
SPLH_surf_interp            = griddata(deg, f, SPLH_surf, deg_interp, f);
SPLV_surf_interp            = griddata(deg, f, SPLV_surf, deg_interp, f);
SPLH_surf_normalized_interp = griddata(deg, f, SPLH_surf_normalized, deg_interp, f);
SPLV_surf_normalized_interp = griddata(deg, f, SPLV_surf_normalized, deg_interp, f);

% ------------------------------------------------------------------------------
% Horizontal Directivity 3D data plot for assymmetric speakers
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(1)
  else
  figure('Name','1', 'WindowState','maximized')
  pause(1)
end
set(gcf,'Name','Horizontal 3D Directivity Data')
subplot(221)
    plot3((0)*ones(length(f),1),f, SPLH_surf_interp(:,deg_interp==(0)),'k', 'LineWidth',1)
    hold on
for k = find(deg_interp==(0)) : find(deg_interp==(180))
    Deg = (k*5-175)*ones(length(f),1);
    SPL = SPLH_surf_interp(:,deg_interp==(k*5-175));
    patch([Deg; nan],[f; nan],[SPL; nan],[f; nan],'EdgeColor','interp','FaceColor','none','LineWidth',2)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Horizontal 3D Directivity Data 0 to +180deg'],'Fontsize',16)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-30 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-00 200]) 
 subplot(222)
    plot3((0)*ones(length(f),1),f, SPLH_surf_normalized_interp(:,deg_interp==(0)),'k', 'LineWidth',1)
    hold on
for k = find(deg_interp==(0)) : find(deg_interp==(180))
    Deg = (k*5-175)*ones(length(f),1);
    SPL = SPLH_surf_normalized_interp(:,deg_interp==(k*5-175));
    patch([Deg; nan],[f; nan],[SPL; nan],[f; nan],'EdgeColor','interp','FaceColor','none','LineWidth',2)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Horizontal 3D Directivity Data 0 to +180deg'],'Fontsize',16)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-30 10])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-00 200])     
subplot(223)
    plot3((0)*ones(length(f),1),f, SPLH_surf_interp(:,deg_interp==(0)),'k', 'LineWidth',1)
    hold on
for k = find(deg_interp==(-170)) : find(deg_interp==(0))
    Deg = (k*5-175)*ones(length(f),1);
    SPL = SPLH_surf_interp(:,deg_interp==(k*5-175));
    patch([Deg; nan],[f; nan],[SPL; nan],[f; nan],'EdgeColor','interp','FaceColor','none','LineWidth',2)
end
    grid minor  
    set(gca,'YScale','log','YDir','reverse') % must be done at this step!
    title([DUT_Name,' Horizontal 3D Directivity Data -170deg to 0'],'Fontsize',16)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-30 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 00]) 
 subplot(224)
    plot3((0)*ones(length(f),1),f, SPLH_surf_normalized_interp(:,deg_interp==(0)),'k', 'LineWidth',1)
    hold on
for k = find(deg_interp==(-170)) : find(deg_interp==(0))
    Deg = (k*5-175)*ones(length(f),1);
    SPL = SPLH_surf_normalized_interp(:,deg_interp==(k*5-175));
    patch([Deg; nan],[f; nan],[SPL; nan],[f; nan],'EdgeColor','interp','FaceColor','none','LineWidth',2)
end
    grid minor  
    set(gca,'YScale','log','YDir','reverse') % must be done at this step!
    title([DUT_Name,' Horizontal 3D Directivity Data -170deg to 0'],'Fontsize',16)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-30 10])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 00])  
    pause(1)
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' Horizontal 3D Directivity data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', '-r90', [DUT_Name,' Horizontal 3D Directivity data.png']) 
end

% ------------------------------------------------------------------------------
% Vertical Directivity 3D data plot for assymmetric speakers
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(2)
  else
  figure('Name','2', 'WindowState','maximized')
end
set(gcf,'Name','Vertical 3D Directivity Data')
subplot(221)
    plot3((0)*ones(length(f),1),f, SPLV_surf_interp(:,deg_interp==(0)),'k', 'LineWidth',1)
    hold on
for k = find(deg_interp==(0)) : find(deg_interp==(180))
    Deg = (k*5-175)*ones(length(f),1);
    SPL = SPLV_surf_interp(:,deg_interp==(k*5-175));
    patch([Deg; nan],[f; nan],[SPL; nan],[f; nan],'EdgeColor','interp','FaceColor','none','LineWidth',2)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Vertical 3D Directivity Data 0 to +180deg'],'Fontsize',16)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-30 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-00 200]) 
 subplot(222)
    plot3((0)*ones(length(f),1),f, SPLV_surf_normalized_interp(:,deg_interp==(0)),'k', 'LineWidth',1)
    hold on
for k = find(deg_interp==(0)) : find(deg_interp==(180))
    Deg = (k*5-175)*ones(length(f),1);
    SPL = SPLV_surf_normalized_interp(:,deg_interp==(k*5-175));
    patch([Deg; nan],[f; nan],[SPL; nan],[f; nan],'EdgeColor','interp','FaceColor','none','LineWidth',2)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Vertical 3D Directivity Data 0 to +180deg'],'Fontsize',16)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-30 10])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-00 200])     
subplot(223)
    plot3((0)*ones(length(f),1),f, SPLV_surf_interp(:,deg_interp==(0)),'k', 'LineWidth',1)
    hold on
for k = find(deg_interp==(-170)) : find(deg_interp==(0))
    Deg = (k*5-175)*ones(length(f),1);
    SPL = SPLV_surf_interp(:,deg_interp==(k*5-175));
    patch([Deg; nan],[f; nan],[SPL; nan],[f; nan],'EdgeColor','interp','FaceColor','none','LineWidth',2)
end
    grid minor  
    set(gca,'YScale','log','YDir','reverse') % must be done at this step!
    title([DUT_Name,' Vertical 3D Directivity Data -170deg to 0'],'Fontsize',16)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-30 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 00]) 
 subplot(224)
    plot3((0)*ones(length(f),1),f, SPLV_surf_normalized_interp(:,deg_interp==(0)),'k', 'LineWidth',1)
    hold on
for k = find(deg_interp==(-170)) : find(deg_interp==(0))
    Deg = (k*5-175)*ones(length(f),1);
    SPL = SPLV_surf_normalized_interp(:,deg_interp==(k*5-175));
    patch([Deg; nan],[f; nan],[SPL; nan],[f; nan],'EdgeColor','interp','FaceColor','none','LineWidth',2)
end
    grid minor  
    set(gca,'YScale','log','YDir','reverse') % must be done at this step!
    title([DUT_Name,' Vertical 3D Directivity Data -170deg to 0'],'Fontsize',16)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-30 10])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 00]) 
    pause(1)
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' Vertical 3D Directivity data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', '-r90', [DUT_Name,' Vertical 3D Directivity data.png']) 
end    

% ------------------------------------------------------------------------------
% Horizontal surface Directivity 3D data plot
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(3)
  else
  figure('Name','3', 'WindowState','maximized')
end   
set(gcf,'Name','3D surface Horizontal Directivity Data')
subplot(121)
    S = surf(deg_interp, f, SPLH_surf_interp);
%     S.EdgeColor = 'none';
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    colormap( jet )
    title([DUT_Name,' Horizontal 3D Directivity Data'],'Fontsize',14)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-50 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 200]) 
subplot(122)
    S = surf(deg_interp, f, SPLH_surf_normalized_interp);
%     S.EdgeColor = 'none';
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Horizontal 3D Normalized Directivity Data'],'Fontsize',14)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-30 20])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 200])  
    pause(1)
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' 3D surface Horizontal Directivity Data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', '-r90', [DUT_Name,' 3D surface Horizontal Directivity Data.png']) 
end

% ------------------------------------------------------------------------------
% Vertical surface Directivity 3D data plot
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(4)
  else
  figure('Name','4', 'WindowState','maximized')
end  
set(gcf,'Name','3D surface Vertical Directivity Data')
subplot(121)
    S = surf(deg_interp, f, SPLV_surf_interp);
%     S.EdgeColor = 'none';
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    colormap( jet )
    title([DUT_Name,' Vertical 3D Directivity Data'],'Fontsize',14)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-50 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 200]) 
subplot(122)
    S = surf(deg_interp, f, SPLV_surf_normalized_interp);
%     S.EdgeColor = 'none';
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Vertical 3D Normalized Directivity Data'],'Fontsize',14)
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-30 20])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 200]) 
    pause(1)
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' 3D surface Vertical Directivity Data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', '-r90', [DUT_Name,' 3D surface Vertical Directivity Data.png']) 
end 
    
% ------------------------------------------------------------------------------
% Horizontal and Vertical Directivity contour plot
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(5)
  else
  figure('Name','5', 'WindowState','maximized')
  pause(1)
end  
set(gcf,'Name','2D surface Directivity Contour Data')
subplot(121)
    surf(deg, f, SPLH_surf_normalized,'EdgeColor', 'None', 'facecolor', 'interp');
    hold on
    contour(deg, f, SPLH_surf_normalized,[-6 -6],'w','LineWidth',2)
    contour(deg, f, SPLH_surf_normalized,[-12 -12],'k','LineWidth',2)
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    colormap( jet )
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-170 180])
    xticks([-160, -140, -120, -100, -80, -60, -40, -20, 0, 20, 40, 60, 80, 100, 120, 140, 160, 180])
    title([DUT_Name,' Horizontal 2D Directivity Data, white -6dB Contour, black -12dB Contour'],'Fontsize',14)
    grid minor
    view(2);
    colorbar 
subplot(122)
    surf(f, deg, SPLV_surf_normalized','EdgeColor', 'None', 'facecolor', 'interp');
    hold on
    contour(f, deg, SPLV_surf_normalized',[-6 -6],'w','LineWidth',2)
    contour(f, deg, SPLV_surf_normalized',[-12 -12],'k','LineWidth',2)
    set(gca,'XScale','log') % must be done at this step!
    colormap( jet )
    xlabel('Frequency [Hz]','Fontsize',14)
    xlim([100 20000]) 
    ylabel('Angle [deg]','Fontsize',14)
    ylim([-170 180])
    yticks([-160, -140, -120, -100, -80, -60, -40, -20, 0, 20, 40, 60, 80, 100, 120, 140, 160, 180])
    title([DUT_Name,' Vertical 2D Directivity Data, white -6dB Contour, black -12dB Contour'],'Fontsize',14)
    grid minor
    view(2);
    colorbar 
    pause(1)
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' 2D surface Directivity Contour Data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', '-r90', [DUT_Name,' 2D surface Directivity Contour Data.png']) 
end   


if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(6)
  else
  figure('Name','6', 'WindowState','maximized')
  pause(1)
end  
set(gcf,'Name','2D surface Directivity Contour only Data')
subplot(121)
    contour(deg, f, SPLH_surf_normalized,[-1 -1],'c','LineWidth',2)
    hold on
    contour(deg, f, SPLH_surf_normalized,[-3 -3],'r','LineWidth',2)
    contour(deg, f, SPLH_surf_normalized,[-6 -6],'b','LineWidth',2)
    contour(deg, f, SPLH_surf_normalized,[-12 -12],'k','LineWidth',2)
    hold on
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-170 180])
%     xticks([-160, -140, -120, -100, -80, -60, -40, -20, 0, 20, 40, 60, 80, 100, 120, 140, 160, 180])
    xticks([-160, -150, -140, -130, -120, -110, -100, -90, -80, -70, -60, -50, -40, -30, -20, -10, 0, 10, 20, 30, 40, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150, 160, 170, 180])

    title([DUT_Name,' Horizontal Directivity 2D Contours'],'Fontsize',16)
    grid minor
    view(2);
    legend ('-1dB Contour','-3dB Contour', '-6dB Contour','-12dB Contour')
subplot(122)
    contour(f, deg, SPLV_surf_normalized',[-1 -1],'c','LineWidth',2)
    hold on
    contour(f, deg, SPLV_surf_normalized',[-3 -3],'r','LineWidth',2)
    contour(f, deg, SPLV_surf_normalized',[-6 -6],'b','LineWidth',2)
    contour(f, deg, SPLV_surf_normalized',[-12 -12],'k','LineWidth',2)
    set(gca,'XScale','log') % must be done at this step!
    xlabel('Frequency [Hz]','Fontsize',14)
    xlim([100 20000]) 
    ylabel('Angle [deg]','Fontsize',14)
    ylim([-170 180])
%     yticks([-160, -140, -120, -100, -80, -60, -40, -20, 0, 20, 40, 60, 80, 100, 120, 140, 160, 180])
    yticks([-160, -150, -140, -130, -120, -110, -100, -90, -80, -70, -60, -50, -40, -30, -20, -10, 0, 10, 20, 30, 40, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150, 160, 170, 180])
    title([DUT_Name,' Vertical 2D Directivity Contours'],'Fontsize',16)
    grid minor
    view(2);
%     legend ('-3dB Contour', '-6dB Contour','-12dB Contour', 'location','northeast')
    pause(1)
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' 2D surface Directivity Contour Only Data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', '-r90', [DUT_Name,' 2D surface Directivity Contour Only Data.png']) 
end   

% ------------------------------------------------------------------------------
% End of script
% ------------------------------------------------------------------------------
 