% Plot directivity data from the Klippel NFS raw data 
% 20200811
% The measurements and scripts provided here are copyrighted by Audio Science Review LLC.
% 
% This work is licensed under the Creative Commons
% Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy
% of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/ or send
% a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
% 
% Highlights of the license are:
% 
% You are free to:
% - Share: copy and redistribute the material in any medium or format
% - Adapt: remix, transform, and build upon the material
% 
% Under the following terms:
% - Attribution: you must give appropriate credit (link and mention of Audio
%   Science Review, https://www.audiosciencereview.com/), provide a link to the
%   license, and indicate if changes were made. You may do so in any reasonable
%   manner, but not in any way that suggests the licensor endorses you or your
%   use.
% - Non Commercial: you may not use the material for commercial purposes.
% - Share Alike: if you remix, transform, or build upon the material, you must
%   distribute your contributions under the same license as the original.
% - No additional restrictions: you may not apply legal terms or technological
%   measures that legally restrict others from doing anything the license permits.
% ------------------------------------------------------------------------------
% Clear variables and house keeping
% ------------------------------------------------------------------------------
clear
close all
clc

% ------------------------------------------------------------------------------
% A prompt will appear to retrieve the Name of the DUT to include it in the 
% titles and name of the saved graphs
% ------------------------------------------------------------------------------
prompt1              = {'Enter the Name of the DUT:'};
dlg_title1           = 'Input Name';
num_lines1           = 1;
AddOpts.Resize       ='on';
AddOpts.WindowStyle  ='normal';
AddOpts.Interpreter  ='tex';
answer1              = inputdlg(prompt1,dlg_title1,num_lines1);
cat1                 = {'a'};
measurement1         = cell2struct(answer1,cat1,1);
DUT_Name             = measurement1.a;

% ------------------------------------------------------------------------------
% Set some variables for the rest of the script
% ------------------------------------------------------------------------------
Pref               = 0.00002;
startRow           = 4;
endRow             = 1000; % Change here for the correct number of lines/rows in the NFS data

% ------------------------------------------------------------------------------
% Load NFS Measurements data Horizontal SPL and Vertical SPL in Octave
% 70 curves (72 minus (ON and 180) which may be measured twice)
% ------------------------------------------------------------------------------
formatSpec = '%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%[^\n]';
delimiter  = '\t';

fileID     = fopen('SPL Horizontal.txt','r');
SPLH       = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter,'HeaderLines', startRow(1)-1, 'EndOfLine', '\n');
fclose(fileID);

fileID     = fopen('SPL Vertical.txt','r');
SPLV       = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter,'HeaderLines', startRow(1)-1, 'EndOfLine', '\n');
f          = SPLH{1,1};
fclose(fileID);

for k = 1 % just hides the calculation of p^2
% -------------------------------------------------------------------------
% Energy 
% -------------------------------------------------------------------------
% SPL = 10*log10( (p/Pref)^2 ); 
% 10. ^ (SPL/10) = (p/Pref)^2;
% p^2 = 10. ^ (SPL/10) * Pref^2;

% Horizontal
ON              = SPLH{1,2};
ONp2            = 10 .^ (ON/10)*Pref^2;
H10deg          = SPLH{1,4};
H10degp2        = 10 .^ (H10deg/10)*Pref^2;
Hneg10deg       = SPLH{1,6};
Hneg10degp2     = 10 .^ (Hneg10deg/10)*Pref^2;
H20deg          = SPLH{1,8};
H20degp2        = 10 .^ (H20deg/10)*Pref^2;
Hneg20deg       = SPLH{1,10};
Hneg20degp2     = 10 .^ (Hneg20deg/10)*Pref^2;
H30deg          = SPLH{1,12};
H30degp2        = 10 .^ (H30deg/10)*Pref^2;
Hneg30deg       = SPLH{1,14};
Hneg30degp2     = 10 .^ (Hneg30deg/10)*Pref^2;
H40deg          = SPLH{1,16};
H40degp2        = 10 .^ (H40deg/10)*Pref^2;
Hneg40deg       = SPLH{1,18};
Hneg40degp2     = 10 .^ (Hneg40deg/10)*Pref^2;
H50deg          = SPLH{1,20};
H50degp2        = 10 .^ (H50deg/10)*Pref^2;
Hneg50deg       = SPLH{1,22};
Hneg50degp2     = 10 .^ (Hneg50deg/10)*Pref^2;
H60deg          = SPLH{1,24};
H60degp2        = 10 .^ (H60deg/10)*Pref^2;
Hneg60deg       = SPLH{1,26};
Hneg60degp2     = 10 .^ (Hneg60deg/10)*Pref^2;
H70deg          = SPLH{1,28};
H70degp2        = 10 .^ (H70deg/10)*Pref^2;
Hneg70deg       = SPLH{1,30};
Hneg70degp2     = 10 .^ (Hneg70deg/10)*Pref^2;
H80deg          = SPLH{1,32};
H80degp2        = 10 .^ (H80deg/10)*Pref^2;
Hneg80deg       = SPLH{1,34};
Hneg80degp2     = 10 .^ (Hneg80deg/10)*Pref^2;
H90deg          = SPLH{1,36};
H90degp2        = 10 .^ (H90deg/10)*Pref^2;
Hneg90deg       = SPLH{1,38};
Hneg90degp2     = 10 .^ (Hneg90deg/10)*Pref^2;
H100deg         = SPLH{1,40};
H100degp2       = 10 .^ (H100deg/10)*Pref^2;
Hneg100deg      = SPLH{1,42};
Hneg100degp2    = 10 .^ (Hneg100deg/10)*Pref^2;
H110deg         = SPLH{1,44};
H110degp2       = 10 .^ (H110deg/10)*Pref^2;
Hneg110deg      = SPLH{1,46};
Hneg110degp2    = 10 .^ (Hneg110deg/10)*Pref^2;
H120deg         = SPLH{1,48};
H120degp2       = 10 .^ (H120deg/10)*Pref^2;
Hneg120deg      = SPLH{1,50};
Hneg120degp2    = 10 .^ (Hneg120deg/10)*Pref^2;
H130deg         = SPLH{1,52};
H130degp2       = 10 .^ (H130deg/10)*Pref^2;
Hneg130deg      = SPLH{1,54};
Hneg130degp2    = 10 .^ (Hneg130deg/10)*Pref^2;
H140deg         = SPLH{1,56};
H140degp2       = 10 .^ (H140deg/10)*Pref^2;
Hneg140deg      = SPLH{1,58};
Hneg140degp2    = 10 .^ (Hneg140deg/10)*Pref^2;
H150deg         = SPLH{1,60};
H150degp2       = 10 .^ (H150deg/10)*Pref^2;
Hneg150deg      = SPLH{1,62};
Hneg150degp2    = 10 .^ (Hneg150deg/10)*Pref^2;
H160deg         = SPLH{1,64};
H160degp2       = 10 .^ (H160deg/10)*Pref^2;
Hneg160deg      = SPLH{1,66};
Hneg160degp2    = 10 .^ (Hneg160deg/10)*Pref^2;
H170deg         = SPLH{1,68};
H170degp2       = 10 .^ (H170deg/10)*Pref^2;
Hneg170deg      = SPLH{1,70};
Hneg170degp2    = 10 .^ (Hneg170deg/10)*Pref^2;
H180deg         = SPLH{1,72};
H180degp2       = 10 .^ (H180deg/10)*Pref^2;

% Vertical
V10deg          = SPLV{1,4};
V10degp2        = 10 .^ (V10deg/10)*Pref^2;
Vneg10deg       = SPLV{1,6};
Vneg10degp2     = 10 .^ (Vneg10deg/10)*Pref^2;
V20deg          = SPLV{1,8};
V20degp2        = 10 .^ (V20deg/10)*Pref^2;
Vneg20deg       = SPLV{1,10};
Vneg20degp2     = 10 .^ (Vneg20deg/10)*Pref^2;
V30deg          = SPLV{1,12};
V30degp2        = 10 .^ (V30deg/10)*Pref^2;
Vneg30deg       = SPLV{1,14};
Vneg30degp2     = 10 .^ (Vneg30deg/10)*Pref^2;
V40deg          = SPLV{1,16};
V40degp2        = 10 .^ (V40deg/10)*Pref^2;
Vneg40deg       = SPLV{1,18};
Vneg40degp2     = 10 .^ (Vneg40deg/10)*Pref^2;
V50deg          = SPLV{1,20};
V50degp2        = 10 .^ (V50deg/10)*Pref^2;
Vneg50deg       = SPLV{1,22};
Vneg50degp2     = 10 .^ (Vneg50deg/10)*Pref^2;
V60deg          = SPLV{1,24};
V60degp2        = 10 .^ (V60deg/10)*Pref^2;
Vneg60deg       = SPLV{1,26};
Vneg60degp2     = 10 .^ (Vneg60deg/10)*Pref^2;
V70deg          = SPLV{1,28};
V70degp2        = 10 .^ (V70deg/10)*Pref^2;
Vneg70deg       = SPLV{1,30};
Vneg70degp2     = 10 .^ (Vneg70deg/10)*Pref^2;
V80deg          = SPLV{1,32};
V80degp2        = 10 .^ (V80deg/10)*Pref^2;
Vneg80deg       = SPLV{1,34};
Vneg80degp2     = 10 .^ (Vneg80deg/10)*Pref^2;
V90deg          = SPLV{1,36};
V90degp2        = 10 .^ (V90deg/10)*Pref^2;
Vneg90deg       = SPLV{1,38};
Vneg90degp2     = 10 .^ (Vneg90deg/10)*Pref^2;
V100deg         = SPLV{1,40};
V100degp2       = 10 .^ (V100deg/10)*Pref^2;
Vneg100deg      = SPLV{1,42};
Vneg100degp2    = 10 .^ (Vneg100deg/10)*Pref^2;
V110deg         = SPLV{1,44};
V110degp2       = 10 .^ (V110deg/10)*Pref^2;
Vneg110deg      = SPLV{1,46};
Vneg110degp2    = 10 .^ (Vneg110deg/10)*Pref^2;
V120deg         = SPLV{1,48};
V120degp2       = 10 .^ (V120deg/10)*Pref^2;
Vneg120deg      = SPLV{1,50};
Vneg120degp2    = 10 .^ (Vneg120deg/10)*Pref^2;
V130deg         = SPLV{1,52};
V130degp2       = 10 .^ (V130deg/10)*Pref^2;
Vneg130deg      = SPLV{1,54};
Vneg130degp2    = 10 .^ (Vneg130deg/10)*Pref^2;
V140deg         = SPLV{1,56};
V140degp2       = 10 .^ (V140deg/10)*Pref^2;
Vneg140deg      = SPLV{1,58};
Vneg140degp2    = 10 .^ (Vneg140deg/10)*Pref^2;
V150deg         = SPLV{1,60};
V150degp2       = 10 .^ (V150deg/10)*Pref^2;
Vneg150deg      = SPLV{1,62};
Vneg150degp2    = 10 .^ (Vneg150deg/10)*Pref^2;
V160deg         = SPLV{1,64};
V160degp2       = 10 .^ (V160deg/10)*Pref^2;
Vneg160deg      = SPLV{1,66};
Vneg160degp2    = 10 .^ (Vneg160deg/10)*Pref^2;
V170deg         = SPLV{1,68};
V170degp2       = 10 .^ (V170deg/10)*Pref^2;
Vneg170deg      = SPLV{1,70};
Vneg170degp2    = 10 .^ (Vneg170deg/10)*Pref^2;
end

% ------------------------------------------------------------------------------
% Set Normalization Axis
% ------------------------------------------------------------------------------
Axis4normalization = SPLH{1,2}; % SPLH{1,2} = ON
max_SPL            = max(ON);
max_scale          = 10*(round(max_SPL/10))+10;
min_scale          = max_scale - 50;

% ------------------------------------------------------------------------------
% LW: Listening Window calculation
% LW  0,  +/-10h, +/-20h, +/-30h, +/-10v do energy average of the 9 curves 
% ------------------------------------------------------------------------------
LW_calc       = 10*log10(((1 * ONp2 + ...
                           1 * H10degp2 + ...
                           1 * Hneg10degp2 + ...
                           1 * H20degp2 + ...
                           1 * Hneg20degp2 + ...
                           1 * H30degp2 + ...
                           1 * Hneg30degp2 + ...
                           1 * V10degp2 + ...
                           1 * Vneg10degp2) / 9 ) / Pref^2);
                        
% ------------------------------------------------------------------------------
% LW: Listening Window plot
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(1)
  else
  figure('Name','1', 'WindowState','maximized')
  pause(1)
end
set(gcf,'Name','LW Data')
    semilogx(f,H10deg,   'LineWidth',1)
    hold on
    semilogx(f,Hneg10deg,'LineWidth',1)
    semilogx(f,H20deg,   'LineWidth',1)
    semilogx(f,Hneg20deg,'LineWidth',1)
    semilogx(f,H30deg,   'LineWidth',1)
    semilogx(f,Hneg30deg,'LineWidth',1)
    semilogx(f,V10deg,   'LineWidth',1)
    semilogx(f,Vneg10deg,'LineWidth',1)
    semilogx(f,ON, 'k','LineWidth',2)
    semilogx(f,LW_calc, 'g','LineWidth',2)
    grid minor
    legend('H10deg','Hneg10deg','H20deg','Hneg20deg','H30deg','Hneg30deg',...
           'V10deg','Vneg10deg','ON','LW','location','northeastoutside')
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    title([DUT_Name,' LW data'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([max_scale-30 max_scale])
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' LW data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', [DUT_Name,' LW data.png']) 
end    
    
% ------------------------------------------------------------------------------
% ER: Early Reflexions calculation
% Floor:     -20v, -30v, -40v do energy average of the 3 curves                                            
% Ceiling:   +40v, +50v, +60v do energy average of the 3 curves 
% Front Wall:  0,  +/-10h, +/-20h, +/-0h do energy average of the 7 curves 
% Side Wall: +/-40h,  +/-50h,  +/-60h,  +/-70h,  +/-80h do energy average  of the 10 curves 
% Rear Wall: +/-90h   +/-100h, +/-110h, +/-120h, +/-130h, +/-140h, +/-150h, +/-160h, +/-170h, 180 
% do energy average of the 19 curves
% ------------------------------------------------------------------------------
Floor_bounce      = 10*log10( (Vneg20degp2 + Vneg30degp2  + Vneg40degp2 ) / 3 / Pref^2); 

Ceiling_bounce    = 10*log10( (V40degp2    + V50degp2     + V60degp2    ) / 3 / Pref^2); 

Front_wall_bounce = 10*log10( (ONp2        + H10degp2     + Hneg10degp2 + Hneg20degp2  + H20degp2  + Hneg30degp2  + ...
                               H30degp2 ) / 7 / Pref^2);

Side_wall_bounce  = 10*log10( (H40degp2    + Hneg40degp2  + H50degp2    + Hneg50degp2  + H60degp2  + Hneg60degp2  + ...
                               H70degp2    + Hneg70degp2  + H80degp2    + Hneg80degp2 ) / 10 / Pref^2);
 
Rear_wall_bounce  = 10*log10( (H90degp2    + Hneg90degp2  + H100degp2   + Hneg100degp2 + H110degp2 + Hneg110degp2 + ...
                               H120degp2   + Hneg120degp2 + H130degp2   + Hneg130degp2 + H140degp2 + Hneg140degp2 + ...
                               H150degp2   + Hneg150degp2 + H160degp2   + Hneg160degp2 + H170degp2 + Hneg170degp2 + ...
                               H180degp2 ) / 19 / Pref^2);
                                                      
ER_calc   =  10*log10( (10 .^ (Floor_bounce/10)*Pref^2      + 10 .^ (Ceiling_bounce/10)*Pref^2   + ...
                        10 .^ (Front_wall_bounce/10)*Pref^2 + 10 .^ (Side_wall_bounce/10)*Pref^2 + ...
                        10 .^ (Rear_wall_bounce/10)*Pref^2 ) / 5 / Pref^2);


if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(2)
  else
  figure('Name','2', 'WindowState','maximized')
  pause(1)
end
set(gcf,'Name','Reflexion Data')
    semilogx(f,Floor_bounce,   'LineWidth',1)
    hold on
    semilogx(f,Ceiling_bounce,'LineWidth',1)
    semilogx(f,Front_wall_bounce,   'LineWidth',1)
    semilogx(f,Side_wall_bounce,'LineWidth',1)
    semilogx(f,Rear_wall_bounce,   'LineWidth',1)
    semilogx(f,ER_calc,'r','LineWidth',2)
    semilogx(f,ON, 'k','LineWidth',2)
    semilogx(f,LW_calc, 'g','LineWidth',2)
    grid minor
    legend('Floor bounce','Ceiling bounce','Front wall bounce','Side wall bounce',...
           'Rear wall bounce','ER','ON','LW','location','northeastoutside')
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    title([DUT_Name,' Reflexion data SPL data'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([max_scale-50 max_scale])
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' Reflexion data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', [DUT_Name,' Reflexion data.png']) 
end

% ------------------------------------------------------------------------------
% Raw directivity data plot
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(3)
  else
  figure('Name','3', 'WindowState','maximized')
  pause(1)
end
set(gcf,'Name','Raw Directivity Data')
subplot(221)
    semilogx(f,SPLH{1,2}, 'k','LineWidth',2)
    hold on
for k = 1:18
    semilogx(f,SPLH{1,4*k}, 'LineWidth',1)
end
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid minor
    title([DUT_Name,' Positive Horizontal SPL data'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([max_scale-50 max_scale])
subplot(222)
    semilogx(f,SPLH{1,2}, 'k','LineWidth',2)
    hold on
for k = 1:17
    semilogx(f,SPLH{1,4*k+2},'LineWidth',1)
end
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid minor
    title([DUT_Name,' Negative Horizontal SPL data'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([max_scale-50 max_scale])
subplot(223)
    semilogx(f,SPLH{1,2}, 'k','LineWidth',2)
    hold on
for k = 1:17
    semilogx(f,SPLV{1,4*k},'LineWidth',1)
    hold on
end
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid minor
    title([DUT_Name,' Positive vertical SPL data'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([max_scale-50 max_scale])
subplot(224)
    semilogx(f,SPLH{1,2}, 'k','LineWidth',2)
    hold on
for k = 1:17
    semilogx(f,SPLV{1,4*k+2},'LineWidth',1)
    hold on
end
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid minor
    title([DUT_Name,' Negative Vertical SPL data'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([max_scale-50 max_scale])
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' Raw Directivity data.png'], '-dpng', '-S1920, 1080');
  else
    print(gcf, '-dpng', [DUT_Name,' Raw Directivity data.png']) 
end

% ------------------------------------------------------------------------------
% Normalized to Axis4normalization directivity data plot
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(4)
  else
  figure('Name','4', 'WindowState','maximized')
  pause(1)
end
set(gcf,'Name','Normalized Directivity Data')
subplot(221)
    semilogx(f,SPLH{1,2} - Axis4normalization, 'k','LineWidth',2)
    hold on
for k = 1:9
    semilogx(f,SPLH{1,4*k} - Axis4normalization, 'LineWidth',1)
end
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid minor
    title([DUT_Name,' Normalized Positive Horizontal SPL data 0 to 90deg'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([-30 10])
subplot(222)
    semilogx(f,SPLH{1,2} - Axis4normalization, 'k','LineWidth',2)
    hold on
for k = 1:9
    semilogx(f,SPLH{1,4*k+2} - Axis4normalization,'LineWidth',1)
end
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid minor
    title([DUT_Name,' Normalized Negative Horizontal SPL data 0 to -90deg'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([-30 10])
subplot(223)
    semilogx(f,SPLH{1,2} - Axis4normalization, 'k','LineWidth',2)
    hold on
for k = 1:9
    semilogx(f,SPLV{1,4*k} - Axis4normalization,'LineWidth',1)
    hold on
end
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid minor
    title([DUT_Name,' Normalized Positive vertical SPL data 0 to 90deg'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([-30 10])
subplot(224)
    semilogx(f,SPLH{1,2} - Axis4normalization, 'k','LineWidth',2)
    hold on
for k = 1:9
    semilogx(f,SPLV{1,4*k+2} - Axis4normalization,'LineWidth',1)
    hold on
end
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid minor
    title([DUT_Name,' Normalized Negative Vertical SPL data 0 to -90deg'],'Fontsize',16)
    xlim([20 20000]) 
    ylim([-30 10])
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' Normalized Directivity data.png'], '-dpng', '-S1920, 1080');
  else
    print(gcf, '-dpng', [DUT_Name,' Normalized Directivity data.png']) 
end  
    
% ------------------------------------------------------------------------------
% Horizontal Directivity 3D data plot
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(5)
  else
  figure('Name','5', 'WindowState','maximized')
  pause(1)
end
set(gcf,'Name','3D Directivity Data')
subplot(221)
    plot3(0*ones(length(f),1),f,SPLH{1,2} , 'k','LineWidth',2)
    hold on
for k = 1:9
    plot3((k*10)*ones(length(f),1),f,SPLH{1,4*k}, 'LineWidth',1)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Horizontal 3D Directivity Data 0 to +90deg'])
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-30 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-00 200]) 
subplot(222)
    plot3(0*ones(length(f),1),f,SPLH{1,2} - Axis4normalization , 'k','LineWidth',2)
    hold on
for k = 1:9
    plot3((k*10)*ones(length(f),1),f,SPLH{1,4*k} - Axis4normalization, 'LineWidth',1)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Horizontal Normalized 3D Directivity Data 0 to +90deg'])
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-25 5]) 
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-00 100])   
subplot(223)
    plot3(0*ones(length(f),1),f,SPLH{1,2} , 'k','LineWidth',2)
    hold on
for k = 1:9
    plot3((-k*10)*ones(length(f),1),f,SPLH{1,4*k+2}, 'LineWidth',1)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse') % must be done at this step!
    title([DUT_Name,' Horizontal 3D Directivity Data -90deg to 0'])
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-30 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 00]) 
subplot(224)
    plot3(0*ones(length(f),1),f,SPLH{1,2} - Axis4normalization , 'k','LineWidth',2)
    hold on
for k = 1:9
    plot3((-k*10)*ones(length(f),1),f,SPLH{1,4*k+2} - Axis4normalization, 'LineWidth',1)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse') % must be done at this step!
    title([DUT_Name,' Horizontal Normalized 3D Directivity Data -90deg to 0'])
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-25 5]) 
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-100 00])      
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' Horizontal 3D Directivity data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', [DUT_Name,' Horizontal 3D Directivity data.png']) 
end

% ------------------------------------------------------------------------------
% Vertical Directivity 3D data plot
% ------------------------------------------------------------------------------
if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(6)
  else
  figure('Name','6', 'WindowState','maximized')
  pause(1)
end
set(gcf,'Name','3D Directivity Data')
subplot(221)
    plot3(0*ones(length(f),1),f,SPLH{1,2} , 'k','LineWidth',2)
    hold on
for k = 1:9
    plot3((k*10)*ones(length(f),1),f,SPLV{1,4*k}, 'LineWidth',1)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Vertical 3D Directivity Data 0 to +90deg'])
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-30 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-00 200]) 
subplot(222)
    plot3(0*ones(length(f),1),f,SPLV{1,2} - Axis4normalization , 'k','LineWidth',2)
    hold on
for k = 1:9
    plot3((k*10)*ones(length(f),1),f,SPLV{1,4*k} - Axis4normalization, 'LineWidth',1)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse','XDir','reverse') % must be done at this step!
    title([DUT_Name,' Vertical Normalized 3D Directivity Data 0 to +90deg'])
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-25 5]) 
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-00 100])   
subplot(223)
    plot3(0*ones(length(f),1),f,SPLV{1,2} , 'k','LineWidth',2)
    hold on
for k = 1:9
    plot3((-k*10)*ones(length(f),1),f,SPLH{1,4*k+2}, 'LineWidth',1)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse') % must be done at this step!
    title([DUT_Name,' Vertical 3D Directivity Data -90deg to 0'])
    zlabel('SPL [dB]','Fontsize',14)
    zlim([max_scale-30 max_scale])
    ylim([max_scale-30 max_scale])
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-200 00]) 
subplot(224)
    plot3(0*ones(length(f),1),f,SPLV{1,2} - Axis4normalization , 'k','LineWidth',2)
    hold on
for k = 1:9
    plot3((-k*10)*ones(length(f),1),f,SPLH{1,4*k+2} - Axis4normalization, 'LineWidth',1)
end
    grid minor
    set(gca,'YScale','log','YDir','reverse') % must be done at this step!
    title([DUT_Name,' Vertical Normalized 3D Directivity Data -90deg to 0'])
    zlabel('SPL [dB]','Fontsize',14)
    zlim([-25 5]) 
    ylabel('Frequency [Hz]','Fontsize',14)
    ylim([100 20000]) 
    xlabel('Angle [deg]','Fontsize',14)
    xlim([-100 00])         
if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' Vertical 3D Directivity data.png'], '-dpng', '-S1920, 1080');
  else
    print(gcf, '-dpng', [DUT_Name,' Vertical 3D Directivity data.png']) 
end

% ------------------------------------------------------------------------------
% End of script
% ------------------------------------------------------------------------------
 

    

    



