% Plot data from the Klippel NFS raw data 
% 20211124
% The measurements and scripts provided here are copyrighted by Audio Science Review LLC.
%
% This work is licensed under the Creative Commons
% Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy
% of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/ or send
% a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
% 
% Highlights of the license are:
% 
% You are free to:
% - Share: copy and redistribute the material in any medium or format
% - Adapt: remix, transform, and build upon the material
% 
% Under the following terms:
% - Attribution: you must give appropriate credit (link and mention of Audio
%   Science Review, https://www.audiosciencereview.com/), provide a link to the
%   license, and indicate if changes were made. You may do so in any reasonable
%   manner, but not in any way that suggests the licensor endorses you or your
%   use.
% - Non Commercial: you may not use the material for commercial purposes.
% - Share Alike: if you remix, transform, or build upon the material, you must
%   distribute your contributions under the same license as the original.
% - No additional restrictions: you may not apply legal terms or technological
%   measures that legally restrict others from doing anything the license permits.
% ------------------------------------------------------------------------------
% Clear variables and house keeping
% ------------------------------------------------------------------------------
clear
close all
clc

% ------------------------------------------------------------------------------
% Call each script in the correct order
% You MUST remove the ALL the "," in the data from the folowing files:
% - SPL Horizontal.txt
% - SPL Vertical.txt
% See "Read me and How to.txt" for details
% Each graph will be saved in the current Octave/Matlab folder
% Each script can be called independently but only
% Octave_Calulate_PIR_SP_LW_ER_vx
% will generate the correct Spinorama
% Prompts will appear to retrieve the Name of the DUT for the naming of the figures 
% ------------------------------------------------------------------------------
tic;
Octave_Calulate_PIR_SP_LW_ER_v4 % un/comment to save the figures
pause(1)
 
% Octave_Plot_H_V_NFS_Data_v3 % un/comment to save the figures
% pause(1)
% 
% Octave_Plot_H_V_NFS_3D_Data_v2 % un/comment to save the figures
% pause(1)
% ------------------------------------------------------------------------------
% Clear variables and house keeping
% ------------------------------------------------------------------------------
clear 
close all

% -------------------------------------------------------------------------
% Example code to load and plot the calculated spinorama data 
% -------------------------------------------------------------------------
Data = cell2mat(struct2cell(load('Spininorama_corrected_F_ON_LW_ER_PIR_SP_SPDI_ERDI_DIoffset')));

f      = Data.data(:,1);
ON     = Data.data(:,2);
LW     = Data.data(:,3);
ER     = Data.data(:,4);
PIR    = Data.data(:,5);
SP     = Data.data(:,6);
SPDI   = Data.data(:,7);
ERDI   = Data.data(:,8);
DIOS   = Data.data(:,9);

DUT_Name        = Data.Name;
DI_OS           = mean(DIOS,1);
plot_range_low  = DI_OS;
plot_range_high = plot_range_low + 50;

% -------------------------------------------------------------------------
% Calculation of the Olive Metric of the unEqed device 
% -------------------------------------------------------------------------
NBD_ON                  = NBD_Response_fnc(f, ON);
NBD_LW                  = NBD_Response_fnc(f, LW);
NBD_PIR                 = NBD_Response_fnc(f, PIR);    
[LFX, f_6dB]            = LFX_Response_fnc(f, SP, LW, 300, 10000);

[SM_PIR, Rsp_PIR, Rlx_PIR, Rhx_PIR] = SM_Response_fnc(f, PIR, 100, 16000);
[SM_ON , Rsp_ON , Rlx_ON , Rhx_ON]  = SM_Response_fnc(f, ON , 100, 16000);
[SM_LW , Rsp_LW , Rlx_LW , Rhx_LW]  = SM_Response_fnc(f, LW , 100, 16000);

% -------------------------------------------------------------------------
% Predicted Preference rating
% -------------------------------------------------------------------------
PPR_ON = 12.69 - 2.49*NBD_ON - 2.99*NBD_PIR - 4.31*LFX + 2.32*SM_PIR;
PPR_LF = 12.69 - 2.49*NBD_ON - 2.99*NBD_PIR - 4.31*log10(14.5) + 2.32*SM_PIR;
PPR_LW = 12.69 - 2.49*NBD_LW - 2.99*NBD_PIR - 4.31*LFX + 2.32*SM_PIR;

% -------------------------------------------------------------------------
% You may have to relocate the legend (drag it to where you want it) and resave the figure (File->save as)
% -------------------------------------------------------------------------

if exist('OCTAVE_VERSION', 'builtin') ~= 0
  figure(1)
  else
  figure('Name','1', 'WindowState','maximized')
  pause(1)
end
set(gcf,'Name','Complete CEDIA Data')
    semilogx(f,ON,'color', 'k','LineWidth',2)
    hold on
    semilogx(f,LW,'color', 'g','LineWidth',2)
    semilogx(f,ER,'r','LineWidth',2)
    semilogx(f,SP,'color', 'b','LineWidth',2)
    semilogx(f,PIR,'color', 'c','LineWidth',2)
    semilogx(f,SPDI + DI_OS,'color', [0.5 0.0 0.5],'LineWidth',2)
    semilogx(f,ERDI + DI_OS,'color', [1.0 0.5 0.0],'LineWidth',2)
%     semilogx(f,DIof,'color', 'y','LineWidth',2)
%     semilogx(f,In_Room+5,'color', 'y','LineWidth',2)
    ylabel('SPL [dB]','Fontsize',14)
    xlabel('Frequency [Hz]','Fontsize',14)
    grid on
    title([DUT_Name,' Scored correct Spinorama CEA2034 Data'],'Fontsize',16)
    xlim([20 20000])
    ylim([plot_range_low plot_range_high])

    semilogx(f(Rlx_PIR:Rhx_PIR),Rsp_PIR,'color', [1.0, 0.84, 0.0],'LineWidth',2)
    semilogx(f,ON - SP + DI_OS,'color', 'y','LineWidth',2)
    legend({'ON', 'LW', 'ER', 'Sound Power', 'PIR', 'Sound Power DI', 'ER DI', 'PIR Direct Linear Regression', 'ON DI'},'Location','NorthWest','NumColumns',3)
    title([DUT_Name, ' Score ON = ',num2str(PPR_ON,'%3.1f'),', Score Sub = ',num2str(PPR_LF,'%3.1f'),', Score LW = ',num2str(PPR_LW,'%3.1f'),', f6dB = ',num2str(f_6dB),', SMPIR = ',num2str(SM_PIR),', NBDON = ',num2str(NBD_ON),', NBDPIR = ',num2str(NBD_PIR),''])

if exist('OCTAVE_VERSION', 'builtin') ~= 0
   print([DUT_Name,' Scored Spinorama Correct data.png'], '-dpng', '-S1920, 1080');
  else
   print(gcf, '-dpng', [DUT_Name,' Scored Spinorama Correct data.png']) 
end 
t = toc

% ------------------------------------------------------------------------------
% End of script
% ------------------------------------------------------------------------------
 

