function [SM_Response , Regression, Regres_flowindx, Regres_fhighindx] = SM_Response_fnc(f, Response, flow, fhigh)

% SM_PIR is Pearson correlation coefficient Coefficient of determination
  
% https://en.wikipedia.org/wiki/Coefficient_of_determination#:~:text=R2%20is%20a%20statistic,predictions%20perfectly%20fit%20the%20data.
% There are several definitions of R2 that are only sometimes equivalent. 
% One class of such cases includes that of simple linear regression where r2 is used instead of R2. 
% When an intercept is included, then r2 is simply the square of the sample correlation coefficient (i.e., r) between the observed outcomes and 
% the observed predictor values.[4] If additional regressors are included, R2 is the square of the coefficient of multiple correlation. 
% In both such cases, the coefficient of determination normally ranges from 0 to 1.
% When evaluating the goodness-of-fit of simulated (Ypred) vs. measured (Yobs) values, 
% it is not appropriate to base this on the R2 of the linear regression (i.e., Yobs= mYpred + b). 
% The R2 quantifies the degree of any linear correlation between Yobs and Ypred, 
% while for the goodness-of-fit evaluation only one specific linear correlation should be taken into consideration: Yobs = 1Ypred + 0 (i.e., the 1:1 line).
% 1 means perfect prediction 
%
% Use for the calculation of the Olive metric
% Regression over the 100 to 16000Hz range 



% [P,S]               = polyfit(log(f(flowindx+1:fhigindx)),PIR(flowindx+1:fhigindx), 1);
% Slope               = P(1);
% Intersect           = P(2);
% Regression          = Intersect + Slope*log(f(flowindx+1:fhigindx));
% R2                  = 1 - (S.normr/norm(Y - mean(Y)))^2 

% flowindx            = find(f <= flow,  1, 'last');
% fhigindx            = find(f <= fhigh, 1, 'last');

[~,flowindx]        = min(abs(f-flow));
[~,fhigindx]        = min(abs(f-fhigh));
Regres_flowindx     = flowindx;
Regres_fhighindx    = fhigindx;

[P,S]               = polyfit( log( f( flowindx:fhigindx ) ), Response( flowindx:fhigindx ), 1);
Regression          = P(2) + P(1)*log( f( flowindx:fhigindx ) );
% SM_PIR              = 1 - (S.normr/norm(Response(flowindx+1:fhigindx) - mean(Response(flowindx+1:fhigindx))))^2;

n                   = length( f( flowindx:fhigindx ) );
X                   = Response( flowindx:fhigindx );
Y                   = P(2) + P(1)*log( f( flowindx:fhigindx ) );
SM_Num              = n*sum(X .* Y) - sum(X) * sum(Y);
SM_Den              = sqrt((n*sum(X .^ 2) - (sum(X))^2)*(n*sum(Y .^ 2) - sum(Y)^2));
SM_Response         = (SM_Num / SM_Den)^2;




